%global soversion 6.13

Name:           dart
Version:        6.13.2
Release:        2%{?dist}
Summary:        Dynamic Animation and Robotics Toolkit

# dart is BSD
# dart/external/convhull_3d: MIT
# dart/external/ikfast: Apache 2
# dart/external/imgui: MIT
# dart/external/lodepng: zlib
# dart/external/odelcpsolver: BSD
License:        BSD-3-Clause and MIT and Apache-2.0 and Zlib
URL:            http://dartsim.github.io/

# Generate tarball to remove "snopt" interface with 
# "all rights reserved" copyright
Source0:        %{name}-%{version}-free.tar.zstd
Source1:        dart_generate_tarball.sh

# See https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:   %{ix86}

BuildRequires:  assimp-devel >= 3.0.0
BuildRequires:  boost-devel
BuildRequires:  bullet-devel 
BuildRequires:  cmake
BuildRequires:  coin-or-Ipopt-devel
BuildRequires:  console-bridge-devel
BuildRequires:  doxygen
BuildRequires:  eigen3-static >= 3.0.5
BuildRequires:  fcl-devel >= 0.2.9
BuildRequires:  flann-devel >= 1.8.4
BuildRequires:  fmt-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  libccd-devel >= 1.4.0
BuildRequires:  lz4-devel
BuildRequires:  NLopt-devel
BuildRequires:  OpenSceneGraph-devel >= 3.0
BuildRequires:  octomap-devel
BuildRequires:  ode-devel
BuildRequires:  pagmo2-devel
BuildRequires:  spdlog-devel
BuildRequires:  tinyxml-devel >= 2.6.2
BuildRequires:  tinyxml2-devel
BuildRequires:  urdfdom-devel

# Disable vendor CMAKE_CXX_FLAGS_RELEASE override
# Correct eigen3 pkg-config module name
Patch0: %{name}-6.13.2-cflags.patch

# Bundled libs
Provides:       bundled(convhull_3d)
Provides:       bundled(ikfast) = 71
Provides:       bundled(imgui) = 1.84
Provides:       bundled(lodepng) = 20160501
Provides:       bundled(odelcpsolver)

%description
DART (Dynamic Animation and Robotics Toolkit) is a collaborative, cross-
platform, open source library created by the Georgia Tech Graphics Lab and 
Humanoid Robotics Lab. The library provides data structures and algorithms 
for kinematic and dynamic applications in robotics and computer animation. 
DART is distinguished by its accuracy and stability due to its use of 
generalized coordinates to represent articulated rigid body systems and 
computation of Lagrange's equations derived from D.Alembert's principle to 
describe the dynamics of motion.

%package devel
Summary: Development files and libraries for ${name}
Requires: %{name}%{_isa} = %{version}-%{release}

%description devel
%{summary}.

%package doc
BuildArch: noarch
Summary: Documentation for %{name}

%description doc
%{summary}.

%prep
%autosetup -Sgendiff -p1 -n %{name}-%{version}
# Remove version pin for Pagmo build against Fedora version
sed -i 's|2.17.0 ||g' cmake/DARTFindpagmo.cmake
# Disable removed snopt interface
sed -i 's|add_subdirectory(snopt)||g' dart/optimizer/CMakeLists.txt

%build
%cmake .. \
  -DDART_BUILD_EXAMPLES=OFF \
  -DDART_BUILD_TUTORIALS=OFF \
  -DCMAKE_BUILD_TYPE=Release
%cmake_build
%cmake_build --target tests

%install
%cmake_install

%check
%ctest || exit 0

%files
%doc README.md CHANGELOG.md
%license LICENSE
%{_libdir}/*.so.%{version}
%{_libdir}/*.so.%{soversion}
%{_datadir}/%{name}

%files devel
%{_includedir}/%{name}
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc

%files doc
%license LICENSE
%{_docdir}/dart

%changelog
* Sat Apr 06 2024 Rich Mattes <richmattes@gmail.com> - 6.13.2-2
- Correct pkgconfig module
- Add pagmo
- Create new source tarball without snopt interface

* Tue Apr 02 2024 Rich Mattes <richmattes@gmail.com> - 6.13.2-1
- Update to release 6.13.2

* Sun Jan 23 2022 Rich Mattes <richmattes@gmail.com> - 6.12.1-1
- Update to release 6.12.1

* Mon Mar 08 2021 Rich Mattes <richmattes@gmail.com> - 6.9.5-1
- Update to release 6.9.5

* Thu Aug 20 2020 Rich Mattes <richmattes@gmail.com> - 6.9.2-2
- Add patch to update pkgconfig external deps.

* Wed Aug 19 2020 Rich Mattes <richmattes@gmail.com> - 6.9.2-1
- Initial package
